#include "widget.h"
#include "ui_widget.h"
#include <QDebug>
#include <QCameraInfo>

//________________________________________________________________________________________________________
Widget::Widget(QWidget *parent) :
    QWidget(parent),
    ui(new Ui::Widget)
{
ui->setupUi(this);
QList<QCameraInfo> cameras = QCameraInfo::availableCameras();
if (cameras.size()) {
                    camera = new QCamera(cameras[0]);
                    if (camera->isCaptureModeSupported(QCamera::CaptureStillImage))
                                camera->setCaptureMode(QCamera::CaptureStillImage);
                    qDebug()<<"connected to "<<cameras[0].deviceName();
                    }
else{
    qDebug() << "No camera found!";
}

imageCapture = new QCameraImageCapture(camera);
connect(imageCapture, SIGNAL(imageCaptured(int,QImage)), this, SLOT(imageCaptured(int,QImage)));
connect(imageCapture, SIGNAL(error(int,QCameraImageCapture::Error,QString)), this, SLOT(cameraError(int,QCameraImageCapture::Error,QString)));

// une seule image
setWindowTitle("Capture d'image - version 1.00");
ui->pushButton->setEnabled(camera->isAvailable());
camera->start();
}

//________________________________________________________________________________________________________
Widget::~Widget()
{
delete ui;
//on shutter button released
camera->stop();
delete camera;
}


//________________________________________________________________________________________________________
void Widget::on_pushButton_clicked()
{
//on pressed shutter button
camera->searchAndLock();
imageCapture->capture();
camera->unlock();
}

//___________________________________________ slot: peinture de l'écran ___________________________________
void  Widget::paintEvent(QPaintEvent *event){
QPainter painter(this);

painter.drawImage(0,0, image);
}

//________________________________________________________________________________________________________
void Widget::cameraError(int id, QCameraImageCapture::Error error, const QString & errorString){
 qDebug()<<errorString;
}

//___________________________________________ slot: une image a été capturée _____________________________
void Widget::imageCaptured(int n, QImage im){
    image = im;
    repaint();
}
