#include "widget.h"
#include "ui_widget.h"
#include <QGroupBox>
#include <QLayout>
#include <iostream>
using namespace std;

Widget::Widget(QWidget *parent) :
    QWidget(parent),
    ui(new Ui::Widget)
{
    ui->setupUi(this);
    this->setLayout(ui->gridLayout);

    // un timer pour mettre à jour l'interface
    timer = new QTimer(this);
    connect(timer, SIGNAL(timeout()), this, SLOT(on_timer()));

    // recherche des sensors disponibles et création de l'interface adhoc
    sensors_init(NULL);
    sensors_chip_name const * cn;
    int c = 0;
    int ylayout=0;
    while ((cn = sensors_get_detected_chips(0, &c)) != 0) {     // pour tous les chips
           // on crée un label avec le nom du chip et on l'insère dans le gridlayout
           QLabel *l = new QLabel(this);
           l->setText(cn->prefix);
           ui->gridLayout->addWidget(l, ylayout++, 0, Qt::AlignVCenter | Qt::AlignRight);
           chiplabels<<l;       // on garde son adresse

           sensors_feature const *feat;
           int f = 0;

           while ((feat = sensors_get_features(cn, &f)) != 0) {     // pour toutes les caractéristiques de ce chip
               sensors_subfeature const *subf;
               int s = 0;

               while ((subf = sensors_get_all_subfeatures(cn, feat, &s)) != 0) {    // tous les senseurs
                   // on crée un label avec le nom de la caractéristique et on l'insère dans le gridlayout
                   QLabel *l = new QLabel(this);
                   l->setText(subf->name);
                   ui->gridLayout->addWidget(l, ylayout, 0);
                   sensorlabels<<l;         // on garde son adresse

                   // on crée un doublespinbox pour la valeur et on l'insère à droite du label ci-dessus
                   QDoubleSpinBox *sp = new QDoubleSpinBox(this);
                   ui->gridLayout->addWidget(sp, ylayout++, 1);
                   sp->setValue(0);
                   sp->setButtonSymbols(QAbstractSpinBox::NoButtons);
                   sp->setMaximum(500);
                  spinboxesValue<<sp;       // on garde son adresse
                  }
           }
       }
   sensors_cleanup();

    timer->start(500);
}

Widget::~Widget()
{
    delete ui;
}

void Widget::on_timer(){
    // recherche des sensors disponibles et on lit leur valeur
    sensors_init(NULL);
    sensors_chip_name const * cn;
    int c = 0;
    int sensorNumber =0;        // pour écrire dans le bon spinbox
    while ((cn = sensors_get_detected_chips(0, &c)) != 0) { // tous les chips
           sensors_feature const *feat;
           int f = 0;

           while ((feat = sensors_get_features(cn, &f)) != 0) { // toutes les caractéristiqes
               sensors_subfeature const *subf;
               int s = 0;

               while ((subf = sensors_get_all_subfeatures(cn, feat, &s)) != 0) {    // toutes les valeurs
                   // lecture du sensor
                   double val;
                   if (subf->flags & SENSORS_MODE_R) {
                       int rc = sensors_get_value(cn, subf->number, &val);
                       if (rc < 0) {
                           // si erreur fond rouge sur le spinbox
                           spinboxesValue[sensorNumber]->setStyleSheet("background-color: rgb(255, 0, 0);");
                       } else {
                           // fond vert si ok
                           spinboxesValue[sensorNumber]->setStyleSheet("background-color: rgb(0, 255, 0);");
                           spinboxesValue[sensorNumber++]->setValue(val);
                       }
                   }
                 }
           }
       }
   sensors_cleanup();
}
