#include "widget.h"
#include "ui_widget.h"
#include <QDebug>
#include <cmath>

Widget::Widget(QWidget *parent) :
    QWidget(parent),
    ui(new Ui::Widget)
{
    srand(time(0));

    //    l'interface
    ui->setupUi(this);
    setLayout(ui->gridLayout);
    ui->spinBox->setMaximum(FSAMPLE/2);

    // Le graphique représentant le signal
    source = new QwtPlot(this);
    ui->gridLayout->addWidget(source, 1,0, 1, 2); // à gauche
    source->setTitle( "source" );
    source->setCanvasBackground( Qt::white );
    source->setAxisScale( QwtPlot::xBottom, 0, (float)NSAMPLE/FSAMPLE);
    source->setAxisScale( QwtPlot::yLeft, -1, +1 );
    source->insertLegend( new QwtLegend() );
    // the grid - axes
    QwtPlotGrid *grid = new QwtPlotGrid();
    grid->attach(source);
    // la courbe  du signal
    sourceCurve = new QwtPlotCurve();
    sourceCurve->setTitle( "signal" );
    sourceCurve->setPen( Qt::blue, 2 );
    sourceCurve->attach(source);


    // Le graphique représentant le spectre de Fourier
    spectre = new QwtPlot(this);
    ui->gridLayout->addWidget(spectre, 1, 3, 1, 2);   // à droite
    spectre->setTitle("spectre");
    spectre->setCanvasBackground( Qt::white);
    spectre->setAxisScale( QwtPlot::xBottom, 0, FSAMPLE/2.);
    spectre->setAxisAutoScale(QwtPlot::yLeft);
    spectre->insertLegend( new QwtLegend());
    // the grid - axes
    QwtPlotGrid *grid2 = new QwtPlotGrid();
    grid2->attach(spectre);

    // la courbe du spectre
    spectreCurve = new QwtPlotCurve();
    spectreCurve->setTitle( "Densité Spectrale" );
    spectreCurve->setPen( Qt::red, 2 ),
    spectreCurve->attach(spectre);

    // allocation des structures de données
    in = (fftw_complex*) fftw_malloc ( sizeof ( fftw_complex ) * NSAMPLE );
    out = (fftw_complex*) fftw_malloc ( sizeof ( fftw_complex ) * NSAMPLE );

    // une sinusoïde pour commencer
    this->on_comboBoxSource_currentIndexChanged(0);
    ui->spinBox->setValue(FSAMPLE/10);

}

//_______________________________________________________________________________
Widget::~Widget()
{
    delete ui;
    //Free up the allocated memory.
    fftw_destroy_plan ( plan_forward );
    fftw_free ( in );
    fftw_free ( out );
}

//________________________________________________________________________________
// changement de profil du signal
void Widget::on_comboBoxSource_currentIndexChanged(int index)
{
double freq = ui->spinBox->value();
double dt = 1./FSAMPLE;
switch (index) {
        case 0:     // sinus
            for (int i = 0; i < NSAMPLE; i++ )
                                {
                                // sinusoïde réelle pure
                                in[i][0] = sin(2*M_PI*freq*i*dt);
                                in[i][1] = 0;
                                }

            break;
        case 1:
            for (int i = 0; i < NSAMPLE; i++ )
                        {
                        // carré
                        in[i][0] = (sin(2*M_PI*freq*i*dt)>0 ? 1 : -1);
                        in[i][1] = 0;
                        }
            break;
        case 2:     // bruit
            for (int i = 0; i < NSAMPLE; i++ )
                        {
                        // bruit banc
                        in[i][0] = (rand()%20000 - 10000)/10000.0;
                        in[i][1] = 0;
                        }
            break;
        case 3:     // pulse
            for (int i = 0; i < NSAMPLE; i++ )
                                {
                                // pulse
                                in[i][0] = fabs(sin(2*M_PI*freq*i*dt))<0.01 ? 1 : 0;
                                in[i][1] = 0;
                                }

            break;
        default:
            break;
        }
// les points sur la courbe du signal
QVector<QPointF> pts;
for (int i=0 ; i<NSAMPLE ; i++)pts.push_back(QPointF(i*dt, in[i][0]));
sourceCurve->setSamples(pts);
source->replot();

//calcul de la TF directe
plan_forward = fftw_plan_dft_1d ( NSAMPLE, in, out, FFTW_FORWARD, FFTW_ESTIMATE );
fftw_execute ( plan_forward );

//  les points sur la courbe du spectre
pts.clear();
double df = (float)FSAMPLE/NSAMPLE;
for (int i=0 ; i<NSAMPLE ; i++)
            pts.push_back(QPointF(i*df, sqrt(pow(out[i][0], 2)+pow(out[i][1], 2))));
spectreCurve->setSamples(pts);
spectre->replot();
}

//________________________________________________
// la fréquence a changée
void Widget::on_spinBox_valueChanged(int arg1)
{
    // on recalcul le signal source et sa TF
    on_comboBoxSource_currentIndexChanged(ui->comboBoxSource->currentIndex());
}
