//*******************************************************************************
//*     Ce programme montre l'utilisation de la classe QFile pour écrire puis   *
//*     lire des fichiers binaires                                              *
//*                                                                             *
//*     nov 2016 - M. GRIMALDI                                                  *
//*******************************************************************************

#include <iostream>
#include <QString>
#include <QFile>
#include <cmath>

using namespace std;

#define SIN_DURATION 2                  // en secondes
#define SIN_AMPLITUDE 100               // amplitude
#define SIN_FREQUENCY 10                // frequence signal en Hz
#define SAMPLE_FREQUENCY 100            // frequence d'échantillonnage
#define DATA_TYPE float                 // le type des données float, double, ...

void reportError(QString msg, bool fatal=false);

//______________________________________________________________________________
int main(int argc, char *argv[])
{
QString fileName = getenv("HOME") + QString("/essai.bin");
QFile file;

file.setFileName(fileName);
file.open(QIODevice::WriteOnly);
if (!file.isOpen())reportError("ouverture du fichier en écriture" + fileName);

// écriture des données dans le fichier

DATA_TYPE data[2];                          // le temps et le signal
float dt = 1./SAMPLE_FREQUENCY;
int nsample = SIN_DURATION*SAMPLE_FREQUENCY;

int i;
for (i=0 ; i<nsample ; i++){
            data[0] = i*dt;
            data[1] = SIN_AMPLITUDE*sin(2*M_PI*SIN_FREQUENCY*data[0]);
            file.write((char *)data, 2*sizeof(DATA_TYPE));
            }

file.close();
cout<<i<<" échantillons sauvés dans "<<fileName.toLatin1().constData()<<endl;


// relecture des données préalablement stockées
file.open(QIODevice::ReadOnly);
if (!file.isOpen())reportError("ouverture du fichier en lecture" + fileName);
i=0;
while (!file.atEnd()){
    file.read((char*)data, 2*sizeof(DATA_TYPE));
    cout<<i<<'\t'<<data[0]<<'\t'<<data[1]<<endl;
    i++;
    }
file.close();

return 0;
}


//______________________________________________________________________________
void reportError(QString msg, bool fatal){
    cout<<"Erreur "<<msg.toLatin1().constData()<<endl;
    if (fatal)exit(0);
}
