//*******************************************************************************
//*     Ce programme montre l'utilisation de la classe QFile pour écrire puis   *
//*     lire des fichiers texte au format CSV (comma separated values)          *
//*                                                                             *
//*     nov 2016 - M. GRIMALDI                                                  *
//*******************************************************************************

#include <iostream>
#include <QString>
#include <QFile>
#include <cmath>
#include <QTextStream>

using namespace std;

#define SIN_DURATION 2                  // en secondes
#define SIN_AMPLITUDE 100               // amplitude
#define SIN_FREQUENCY 10                // frequence signal en Hz
#define SAMPLE_FREQUENCY 100            // frequence d'échantillonnage

void reportError(QString msg, bool fatal=false);

//______________________________________________________________________________
int main(int argc, char *argv[])
{
QString fileName = getenv("HOME") + QString("/essai.csv");
QFile file;
QTextStream flux;

file.setFileName(fileName);
file.open(QIODevice::WriteOnly);
if (!file.isOpen())reportError("ouverture du fichier en écriture" + fileName);


// écriture des données dans le fichier
flux.setDevice(&file);
float t, y;                 // le temps et le signal
float dt = 1./SAMPLE_FREQUENCY;
int nsample = SIN_DURATION*SAMPLE_FREQUENCY;

file.write("time\tsignal\r\n");         // la ligne de titre
int i;
for (i=0 ; i<nsample ; i++){
            t = i*dt;
            y = SIN_AMPLITUDE*sin(2*M_PI*SIN_FREQUENCY*t);
//            QString br; // une chaine brouillon
//            br.sprintf("%f\t%f\r\n", t, y);
//            br.replace(".", ",");                           // séparateur , dans openOffice
//            file.write(br.toLatin1());
            flux<<t<<'\t'<<y<<"\n";
            }

file.close();
cout<<i<<" échantillons sauvés dans "<<fileName.toLatin1().constData()<<endl;


// relecture des données préalablement stockées
file.open(QIODevice::ReadOnly);
if (!file.isOpen())reportError("ouverture du fichier en lecture" + fileName);
i=0;
while (!file.atEnd()){
    QByteArray data;
    data = file.readLine();
    cout<<i<<'\t'<<data.constData()<<endl;
    i++;
    }
file.close();


return 0;
}


//______________________________________________________________________________
void reportError(QString msg, bool fatal){
    cout<<"Erreur "<<msg.toLatin1().constData()<<endl;
    if (fatal)exit(0);
}
